%global hawkey_version 0.8.0
%global librepo_version 1.7.19
%global libcomps_version 0.1.8
%global rpm_version 4.13.0
%global min_plugins_core 1.0.0
%global min_plugins_extras 0.10.0
%global dnf_langpacks_ver 0.15.1-3

%global confdir %{_sysconfdir}/dnf

%global pluginconfpath %{confdir}/plugins
%global py2pluginpath %{python2_sitelib}/dnf-plugins
%global py3pluginpath %{python3_sitelib}/dnf-plugins

# Iurt causes problems when fake ttys are being created
# for the test framework to do its tests, causing them to fail.
# Until this is resolved, tests will not be executed by default.
%bcond_with tests

# Fedora package release versions are committed as versions in upstream
#global prerel rc2
%global origrel %{?prerel:0.%{prerel}.}1
%global rel 1

Name:           dnf
Version:        2.3.0
Release:        %mkrel %{?prerel:0.%{prerel}.}%{rel}
Summary:        Package manager forked from Yum, using libsolv as a dependency resolver
Group:          System/Packaging
# For a breakdown of the licensing, see PACKAGE-LICENSING
License:        GPLv2+ and GPLv2 and GPL
URL:            https://github.com/rpm-software-management/dnf
Source0:        %{url}/archive/%{name}-%{version}-%{origrel}.tar.gz

# Mageia patches
# Add armv5tl to arm basearch
# From: https://github.com/rpm-software-management/dnf/pull/765
Patch1001:      dnf-2.1.0-Add-armv5tl-to-arm-basearch.patch

BuildArch:      noarch
BuildRequires:  cmake
BuildRequires:  gettext
BuildRequires:  python-bugzilla
BuildRequires:  python-sphinx
BuildRequires:  python-sphinx_rtd_theme
BuildRequires:  systemd-devel

# For autosetup
BuildRequires:  git-core

Requires:   python3-dnf = %{version}-%{release}
Recommends: dnf-yum
Recommends: dnf-plugins-core
Conflicts:  dnf-plugins-core < %{min_plugins_core}
# dnf-langpacks is no longer supported
Obsoletes:  dnf-langpacks < %{dnf_langpacks_ver}
Requires(post):     systemd
Requires(preun):    systemd
Requires(postun):   systemd
Provides:           dnf-command(autoremove)
Provides:           dnf-command(check-update)
Provides:           dnf-command(clean)
Provides:           dnf-command(distro-sync)
Provides:           dnf-command(downgrade)
Provides:           dnf-command(group)
Provides:           dnf-command(history)
Provides:           dnf-command(info)
Provides:           dnf-command(install)
Provides:           dnf-command(list)
Provides:           dnf-command(makecache)
Provides:           dnf-command(mark)
Provides:           dnf-command(provides)
Provides:           dnf-command(reinstall)
Provides:           dnf-command(remove)
Provides:           dnf-command(repolist)
Provides:           dnf-command(repoquery)
Provides:           dnf-command(repository-packages)
Provides:           dnf-command(search)
Provides:           dnf-command(updateinfo)
Provides:           dnf-command(upgrade)
Provides:           dnf-command(upgrade-to)
%description
Package manager forked from Yum, using libsolv as a dependency resolver.

%package conf
Summary:    Configuration files for DNF
Group:      System/Packaging
# dnf-langpacks is no longer supported
Obsoletes:  dnf-langpacks-conf < %{dnf_langpacks_ver}

%description conf
Configuration files for DNF.

%package yum
Group:      System/Packaging
# As of yum 3.4.3-14, /usr/bin/yum is now /usr/bin/yum-deprecated,
# which allows both on the same system for tools like Mock
# to target distros using yum as appropriate. (ngompa)
Conflicts:  yum < 3.4.3-14
Requires:   dnf = %{version}-%{release}
Summary:    As a Yum CLI compatibility layer, supplies /usr/bin/yum redirecting to DNF
%description yum
As a Yum CLI compatibility layer, supplies /usr/bin/yum redirecting to DNF.

%package -n python2-dnf
Summary:    Python 2 interface to DNF
Group:      System/Packaging
Provides:   python-dnf = %{version}-%{release}
BuildRequires:  python2-devel
BuildRequires:  python2-gpg
BuildRequires:  python-lzma
BuildRequires:  python2-hawkey >= %{hawkey_version}
BuildRequires:  python-iniparse
BuildRequires:  python2-libcomps >= %{libcomps_version}
BuildRequires:  python2-librepo >= %{librepo_version}
BuildRequires:  python-nose
BuildRequires:  python2-rpm >= %{rpm_version}
Recommends: bash-completion
Recommends: python-dbus
Requires:   dnf-conf = %{version}-%{release}
Requires:   mageia-dnf-conf
Requires:   deltarpm
Requires:   python2-gpg
Requires:   python-lzma
Requires:   python2-hawkey >= %{hawkey_version}
Requires:   python-iniparse
Requires:   python2-libcomps >= %{libcomps_version}
Requires:   python2-librepo >= %{librepo_version}
Requires:   python2-rpm >= %{rpm_version}
# DNF 2.0 doesn't work with old plugins
Conflicts:  python2-dnf-plugins-core < %{min_plugins_core}
Conflicts:  python2-dnf-plugins-extras-common < %{min_plugins_extras}
# dnf-langpacks is no longer supported
Obsoletes:  python2-dnf-langpacks < %{dnf_langpacks_ver}

%description -n python2-dnf
Python 2 interface to DNF.

%package -n python3-dnf
Summary:    Python 3 interface to DNF
Group:      System/Packaging
BuildRequires:  python3-devel
BuildRequires:  python3-hawkey >= %{hawkey_version}
BuildRequires:  python3-iniparse
BuildRequires:  python3-libcomps >= %{libcomps_version}
BuildRequires:  python3-librepo >= %{librepo_version}
BuildRequires:  python3-nose
BuildRequires:  python3-gpg
BuildRequires:  python3-rpm >= %{rpm_version}
Recommends: bash-completion
Recommends: python3-dbus
Requires:   dnf-conf = %{version}-%{release}
Requires:   mageia-dnf-conf
Requires:   deltarpm
Requires:   python3-hawkey >= %{hawkey_version}
Requires:   python3-iniparse
Requires:   python3-libcomps >= %{libcomps_version}
Requires:   python3-librepo >= %{librepo_version}
Requires:   python3-gpg
Requires:   python3-rpm >= %{rpm_version}
# DNF 2.0 doesn't work with old plugins
Conflicts:  python3-dnf-plugins-core < %{min_plugins_core}
Conflicts:  python3-dnf-plugins-extras-common < %{min_plugins_extras}
# dnf-langpacks is no longer supported
Obsoletes:  python3-dnf-langpacks < %{dnf_langpacks_ver}

%description -n python3-dnf
Python 3 interface to DNF.

%package automatic
Summary:    Alternative CLI to "dnf upgrade" suitable for automatic, regular execution
Group:      System/Packaging
BuildRequires:  systemd-devel
Requires:   dnf = %{version}-%{release}
Requires(post):     systemd
Requires(preun):    systemd
Requires(postun):   systemd
%description automatic
Alternative CLI to "dnf upgrade" suitable for automatic, regular execution.

%prep
%autosetup -n %{name}-%{name}-%{version}-%{origrel} -S git

mkdir py3

%build
%cmake
%make_build
make doc-man

pushd ../py3
%cmake -DPYTHON_DESIRED:str=3 -DWITH_MAN=0 ../../
%make_build
popd

%install
pushd ./build
%make_install
popd
%find_lang %{name}

pushd ./py3/build
%make_install
popd

mkdir -p %{buildroot}%{pluginconfpath}
mkdir -p %{buildroot}%{py2pluginpath}
mkdir -p %{buildroot}%{py3pluginpath}
mkdir -p %{buildroot}%{_localstatedir}/log
mkdir -p %{buildroot}%{_var}/cache/dnf
touch %{buildroot}%{_localstatedir}/log/%{name}.log
ln -sr %{buildroot}%{_bindir}/dnf-3 %{buildroot}%{_bindir}/dnf
mv %{buildroot}%{_bindir}/dnf-automatic-3 %{buildroot}%{_bindir}/dnf-automatic
rm %{buildroot}%{_bindir}/dnf-automatic-2

%if %{with tests}
%check
pushd ./build
make ARGS="-V" test
popd

pushd ./py3/build
make ARGS="-V" test
popd
%endif

%files -f %{name}.lang
%license COPYING PACKAGE-LICENSING
%doc AUTHORS README.rst
%{_bindir}/dnf
%{_mandir}/man8/dnf.8.*
%{_mandir}/man8/yum2dnf.8.*
%{_unitdir}/dnf-makecache.service
%{_unitdir}/dnf-makecache.timer
%{_var}/cache/dnf

%files conf
%license COPYING PACKAGE-LICENSING
%doc AUTHORS README.rst
%dir %{confdir}
%dir %{pluginconfpath}
%dir %{confdir}/protected.d
%config(noreplace) %{confdir}/%{name}.conf
%config(noreplace) %{confdir}/protected.d/%{name}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%ghost %{_localstatedir}/log/hawkey.log
%ghost %{_localstatedir}/log/%{name}.log
%ghost %{_localstatedir}/log/%{name}.librepo.log
%ghost %{_localstatedir}/log/%{name}.rpm.log
%ghost %{_localstatedir}/log/%{name}.plugin.log
%ghost %{_sharedstatedir}/%{name}
%ghost %{_sharedstatedir}/%{name}/groups.json
%ghost %{_sharedstatedir}/%{name}/yumdb
%ghost %{_sharedstatedir}/%{name}/history
%{_sysconfdir}/bash_completion.d/dnf
%{_mandir}/man5/dnf.conf.5.*
%{_tmpfilesdir}/dnf.conf
# We don't have ABRT/libreport in Mageia, so exclude this
%exclude %{_sysconfdir}/libreport/events.d/collect_dnf.conf

%files yum
%license COPYING PACKAGE-LICENSING
%doc AUTHORS README.rst
%{_bindir}/yum
%{_mandir}/man8/yum.8.*

%files -n python2-dnf
%license COPYING PACKAGE-LICENSING
%{_bindir}/dnf-2
%doc AUTHORS README.rst
%exclude %{python2_sitelib}/dnf/automatic
%{python2_sitelib}/dnf/
%dir %{py2pluginpath}

%files -n python3-dnf
%license COPYING PACKAGE-LICENSING
%doc AUTHORS README.rst
%{_bindir}/dnf-3
%exclude %{python3_sitelib}/dnf/automatic
%{python3_sitelib}/dnf/
%dir %{py3pluginpath}

%files automatic
%license COPYING PACKAGE-LICENSING
%doc AUTHORS
%{_bindir}/%{name}-automatic
%config(noreplace) %{confdir}/automatic.conf
%{_mandir}/man8/%{name}.automatic.8.*
%{_unitdir}/%{name}-automatic-notifyonly.service
%{_unitdir}/%{name}-automatic-notifyonly.timer
%{_unitdir}/%{name}-automatic-download.service
%{_unitdir}/%{name}-automatic-download.timer
%{_unitdir}/%{name}-automatic-install.service
%{_unitdir}/%{name}-automatic-install.timer

%{python3_sitelib}/%{name}/automatic

%post
%systemd_post %{name}-makecache.timer

%preun
%systemd_preun %{name}-makecache.timer

%postun
%systemd_postun_with_restart %{name}-makecache.timer

%post automatic
%systemd_post %{name}-automatic-notifyonly.timer
%systemd_post %{name}-automatic-download.timer
%systemd_post %{name}-automatic-install.timer

%preun automatic
%systemd_preun %{name}-automatic-notifyonly.timer
%systemd_preun %{name}-automatic-download.timer
%systemd_preun %{name}-automatic-install.timer

%postun automatic
%systemd_postun_with_restart %{name}-automatic-notifyonly.timer
%systemd_postun_with_restart %{name}-automatic-download.timer
%systemd_postun_with_restart %{name}-automatic-install.timer



%changelog
* Wed Apr 12 2017 ngompa <ngompa> 2.3.0-1.mga6
+ Revision: 1096478
- Update to 2.3.0

* Sun Apr 02 2017 ngompa <ngompa> 2.2.0-1.mga6
+ Revision: 1095682
- Update to 2.2.0

* Thu Mar 23 2017 ngompa <ngompa> 2.1.1-1.mga6
+ Revision: 1094582
- Update to 2.1.1

* Sun Mar 19 2017 ngompa <ngompa> 2.1.0-2.mga6
+ Revision: 1093594
- Add patch to add armv5tl to arm basearch

* Fri Feb 17 2017 ngompa <ngompa> 2.1.0-1.mga6
+ Revision: 1086552
- Upgrade to 2.1.0

* Thu Dec 15 2016 ngompa <ngompa> 2.0.0-1.mga6
+ Revision: 1075398
- Upgrade to final release of 2.0.0

* Sun Dec 04 2016 ngompa <ngompa> 2.0.0-0.6.rc2.mga6
+ Revision: 1071912
- Add patch to fix rendering repo descriptions (rhbz#1387754)

* Fri Dec 02 2016 ngompa <ngompa> 2.0.0-0.5.rc2.mga6
+ Revision: 1071666
- Update to 2.0.0-rc2

* Fri Dec 02 2016 ngompa <ngompa> 2.0.0-0.4.rc1.mga6
+ Revision: 1071587
- Ensure None isn't passed to librepo callback (rhbz#1387754)

* Sun Nov 27 2016 ngompa <ngompa> 2.0.0-0.3.rc1.mga6
+ Revision: 1070520
- Bump for rebuilding against core/release

* Sat Nov 26 2016 ngompa <ngompa> 2.0.0-0.2.rc1.mga6
+ Revision: 1070278
- Add patch to fix recursion in queries

* Sat Nov 26 2016 ngompa <ngompa> 2.0.0-0.1.rc1.mga6
+ Revision: 1070226
- Upgrade to 2.0rc1
- Add Conflicts for older versions of dnf-plugins-(core|extras)
- Add patch to fix dnf history (info|redo|undo) last
- Rework the spec slightly for pre-release setup
- Add BuildConflicts for python-hawkey >= 0.7.0

* Sun Sep 04 2016 ngompa <ngompa> 1.1.10-2.mga6
+ Revision: 1049981
- Add Conflicts for python-hawkey >= 0.7.0

* Sat Aug 20 2016 ngompa <ngompa> 1.1.10-1.mga6
+ Revision: 1047195
- Update to 1.1.10, drop upstreamed patches

* Sat Jun 04 2016 ngompa <ngompa> 1.1.9-3.mga6
+ Revision: 1020243
- Add Recommends to install /usr/bin/yum compatibility package
- Add patch to remove message to migrate from yum, as we never used it

* Sat May 28 2016 ngompa <ngompa> 1.1.9-2.mga6
+ Revision: 1019087
- Sync with Fedora patches backported from upstream

* Thu May 19 2016 ngompa <ngompa> 1.1.9-1.mga6
+ Revision: 1016907
- Update to 1.1.9

* Mon Apr 25 2016 ngompa <ngompa> 1.1.8-2.mga6
+ Revision: 1005992
- Add requirement for mageia-dnf-conf

* Sun Apr 10 2016 ngompa <ngompa> 1.1.8-1.mga6
+ Revision: 1000151
- Update to dnf-1.1.8

  + tv <tv>
    - python3 is mandatory

* Sun Mar 13 2016 tv <tv> 1.1.7-1.mga6
+ Revision: 990297
- sync patches with FC
- sync patches with FC
- new release

* Mon Feb 08 2016 ngompa <ngompa> 1.1.6-2.mga6
+ Revision: 942474
- Sync patches from Fedora (fixes rhbz#1303149 & rhbz#1302934)

* Sun Jan 31 2016 ngompa <ngompa> 1.1.6-1.mga6
+ Revision: 929344
- Update to 1.1.6

* Sun Jan 24 2016 ngompa <ngompa> 1.1.5-1.mga6
+ Revision: 926801
- Update to dnf-1.1.5

* Sun Oct 25 2015 ngompa <ngompa> 1.1.3-2.mga6
+ Revision: 895438
- Remove useless %%posttrans since we never had dnf < 1.0.2
- Update dnf-yum Conflicts to allow yum-3.4.3-14 to coexist with it

* Fri Oct 16 2015 shlomif <shlomif> 1.1.3-1.mga6
+ Revision: 892007
- New version 1.1.3 (thx to Neal Gompa)

* Tue Oct 13 2015 shlomif <shlomif> 1.1.2-5.mga6
+ Revision: 890459
- Fix trailing dots (Thanks to Neal Gompa
- Cleanups and disable tests - thanks to Neal Gompa
- Importing dnf thanks to Neal Gompa and from Fedora

